@@ -118,20 +118,29 @@ class Automaton(ABC):
     @abstractmethod
     def run(self):
         """The run() abstract method has to be implemented in Automaton subclasses in order the
-        define what an automaton has to do on each generation. This method will be also in charge
-        of updating the automaton status property on each generation."""
+        define what an automaton has to do on each generation."""
+        pass
+
+    @abstractmethod
+    def get_status(self):
+        """The get_status() abstract method subclasses implementation will return the status of an
+        automaton.
+        :return: AutomatonStatus
+        """
         pass
 
     @classmethod
     def describe(cls, short=True):
         """The describe() method is a convenience method used to get some textual information
-        about an automaton (e.g. its status).
+        about an automata class.
         This method takes an optional boolean keyword parameter named short to specify if the
         reply has to be short or not.
 
         :type short: bool
         :return: str
         """
+        # TODO: this is a class method, should it be an instance method instead?
+        #  Or do we need a separate method to report the current state of the automaton?
         return cls.__name__
 
 
